'use strict';
var generators = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');

module.exports = generators.Base.extend({
  //Ask for user input
  prompting: function () {
    return this.prompt([{
      type    : 'input',
      name    : 'name',
      message : 'Your project name',
      default : this.appname // Default to current folder name
    }]).then(function (answers) {
      this.appname = answers.name.replace(/\s+/g, '-');
      this.props = answers;
    }.bind(this));
  },

  _private_copy: function(source, dest) {
    this.fs.copy(
      this.templatePath(source),
      this.destinationPath(dest)
    );
  },

  _private_copyTpl: function(source, dest, tpl) {
    this.fs.copyTpl(
      this.templatePath(source),
      this.destinationPath(dest), 
      tpl
    );
  },

  //Writing Logic here
  writing: function() {
    //root
    this._private_copyTpl('_package.json', 'package.json', { name: this.appname });
    this._private_copy('_gitignore', '.gitignore');
    this._private_copy('_gulpfile.js', 'gulpfile.js');
    this._private_copy('_tsconfig.json', 'tsconfig.json');
    this._private_copy('_webpack.config.Dev.js', 'webpack.config.Dev.js');
    this._private_copy('_webpack.config.Prod.js', 'webpack.config.Prod.js');

    //root/public/vendor
    this._private_copy('_public/_vendor/_jquery.min.js', 'public/vendor/jquery.min.js');
    this._private_copy('_public/_vendor/_react-dom.min.js', 'public/vendor/react-dom.min.js');
    this._private_copy('_public/_vendor/_react-redux.min.js', 'public/vendor/react-redux.min.js');
    this._private_copy('_public/_vendor/_react-with-addons.min.js', 'public/vendor/react-with-addons.min.js');
    this._private_copy('_public/_vendor/_redux.min.js', 'public/vendor/redux.min.js');
    this._private_copy('_public/_vendor/_redux-thunk.min.js', 'public/vendor/redux-thunk.min.js');
    
    //root/public
    this._private_copyTpl('_public/_index.html', 'public/index.html', { name: this.appname });

    //root/src
    this._private_copy('_src/_actions/_contact-actions.tsx', 'src/actions/contact-actions.tsx');
    this._private_copy('_src/_components/_contact-component.tsx', 'src/components/contact-component.tsx');
    this._private_copy('_src/_interfaces/_contact.d.ts', 'src/interfaces/contact.d.ts');
    this._private_copy('_src/_interfaces/_contact-strings.ts', 'src/interfaces/contact-strings.ts');
    this._private_copy('_src/_reducers/_contact-reducer.tsx', 'src/reducers/contact-reducer.tsx');
    this._private_copy('_src/_reducers/_root-reducer.tsx', 'src/reducers/root-reducer.tsx');
    this._private_copy('_src/_store/_configureStore.dev.tsx', 'src/store/configureStore.dev.tsx');
    this._private_copy('_src/_store/_configureStore.tsx', 'src/store/configureStore.tsx');
    this._private_copy('_src/_index.tsx', 'src/index.tsx');

    //root/typings
    this._private_copy('_typings/_index.d.ts', 'typings/index.d.ts');
  },

  //install NPM packages
  install: function() {
    this.npmInstall();
  }
});
